/*
 * Copyright 2000-2005 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.samples;

import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.wm.ToolWindow;
import com.intellij.openapi.wm.ToolWindowAnchor;
import com.intellij.openapi.wm.ToolWindowManager;
import com.intellij.util.ui.UIUtil;
import tree.HyperLinkCellEditor;
import tree.HyperLinkCellRenderer;
import tree.MyBasicTreeUI;

import javax.swing.*;
import javax.swing.tree.DefaultMutableTreeNode;
import java.awt.*;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;

public class SimpleToolWindowPlugin implements ProjectComponent {
  private Project myProject;

  private ToolWindow myToolWindow;
  private JPanel myContentPanel;

  public static final String TOOL_WINDOW_ID = "SimpleToolWindow";

  public SimpleToolWindowPlugin(Project project) {
    myProject = project;
  }

  public void projectOpened() {
    initToolWindow();
  }

  public void projectClosed() {
    unregisterToolWindow();
  }

  public void initComponent() {
    // empty
  }

  public void disposeComponent() {
    // empty
  }

  public String getComponentName() {
    return "SimpleToolWindow.SimpleToolWindowPlugin";
  }

  private void initToolWindow() {
    ToolWindowManager toolWindowManager = ToolWindowManager.getInstance(myProject);

    myContentPanel = new JPanel(new BorderLayout());

      final String[] strs = {"swing",              // 0
              "package",            // 1
              "<htlml><a href=\"bean::myBean\">java.awt.swing</a>"
                      + "com.sun.java.swing <a href=\"method::test\">test</a></html>", // 2
              "javax.swing",        // 3
              "JTree"};             // 4

      final DefaultMutableTreeNode[] nodes = new DefaultMutableTreeNode[strs.length];
      for (int i = 0; i < strs.length; i++) {
          nodes[i] = new DefaultMutableTreeNode(strs[i]);
      }
      nodes[0].add(nodes[1]);
      nodes[1].add(nodes[2]);
      nodes[1].add(nodes[3]);
      nodes[0].add(nodes[4]);

      final JTree tree = new JTree(nodes[0]);
      tree.setCellRenderer(new HyperLinkCellRenderer());
      tree.setCellEditor(new HyperLinkCellEditor());
      tree.setRowHeight(0);
      tree.setEditable(true);
      tree.setUI(new MyBasicTreeUI());
      tree.addMouseMotionListener(new MouseMotionListener() {
          public void mouseDragged(final MouseEvent e) {
          }

          public void mouseMoved(final MouseEvent e) {
              tree.startEditingAtPath(tree.getPathForLocation(e.getX(), e.getY()));
          }
      });

      final JScrollPane sp = new JScrollPane();
      sp.getViewport().add(tree);

    myContentPanel.setBackground(UIUtil.getTreeTextBackground());
      myContentPanel.add(sp);
//    myContentPanel.add(new JLabel("Hello World!", JLabel.CENTER), BorderLayout.CENTER);

    myToolWindow = toolWindowManager.registerToolWindow(TOOL_WINDOW_ID, myContentPanel, ToolWindowAnchor.LEFT);
    myToolWindow.setTitle("SimpleWindow");
  }

  private void unregisterToolWindow() {
    ToolWindowManager toolWindowManager = ToolWindowManager.getInstance(myProject);
    toolWindowManager.unregisterToolWindow(TOOL_WINDOW_ID);
  }
}
