package tree;

import javax.swing.*;
import javax.swing.event.HyperlinkListener;
import javax.swing.event.HyperlinkEvent;
import javax.swing.plaf.ColorUIResource;
import java.awt.*;
import java.io.BufferedReader;
import java.io.StringReader;
import java.io.IOException;

class TreeEditorPane extends JEditorPane {
    TreeEditorPane() {
        setContentType("text/html");
        setFocusable(true);
        setOpaque(true);
        setEditable(false);
        addHyperlinkListener(new HyperlinkListener() {
            public void hyperlinkUpdate(final HyperlinkEvent e) {
                if (HyperlinkEvent.EventType.ACTIVATED == e.getEventType()) {
                    System.out.println("hyperlink: " + e.getDescription());
                }
            }
        });
    }

    Dimension _preferredSize;

    public void setBackground(Color color) {
        if (color instanceof ColorUIResource) {
            color = null;
        }
        super.setBackground(color);
    }

    public void setPreferredSize(final Dimension d) {
        if (d != null) {
            _preferredSize = d;
        }
    }

    public Dimension getPreferredSize() {
        return _preferredSize;
    }

    public void setText(final String str) {
        final FontMetrics fm = getToolkit().getFontMetrics(getFont());
        final BufferedReader br = new BufferedReader(new StringReader(str));
        String line;
        int maxWidth = 0, lines = 0;
        try {
            while ((line = br.readLine()) != null) {
                final int width = SwingUtilities.computeStringWidth(fm, line);
                if (maxWidth < width) {
                    maxWidth = width;
                }
                lines++;
            }
        } catch (IOException ex) {
            ex.printStackTrace();
        }
        lines = (lines < 1) ? 1 : lines;
        final int height = fm.getHeight() * lines;
        setPreferredSize(new Dimension(maxWidth + 6, height));
        super.setText(str);
    }

    void setSelect(final boolean isSelected) {
        final Color bColor;
        if (isSelected) {
            bColor = UIManager.getColor("Tree.selectionBackground");
        } else {
            bColor = UIManager.getColor("Tree.textBackground");
        }
        super.setBackground(bColor);
    }

    void setFocus(final boolean hasFocus) {
        if (hasFocus) {
            final Color lineColor = UIManager.getColor("Tree.selectionBorderColor");
            setBorder(BorderFactory.createLineBorder(lineColor));
        } else {
            setBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1));
        }
    }
}
